#
# spec file for package ant
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
# Copyright (c) 2000-2009, JPackage Project
# All rights reserved.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_without bootstrap
%bcond_with junit
%bcond_with antlr

# disable javadoc build on arm platform - it delays a build a lot
# mvyskocil: ifarch does not work for noarch packages ...
%if %{_arch} != arm
%global build_javadoc 1
%else
%global build_javadoc 0
%endif

%global ant_home %{_datadir}/ant

%global major_version 1.9

Name:           ant
Version:        1.9.4
Release:        11.4
Summary:        Java-based build tool
License:        Apache-2.0
Group:          Development/Tools/Building
Url:            http://ant.apache.org/
Source0:        http://www.apache.org/dist/ant/source/apache-ant-%{version}-src.tar.bz2
Source1:        apache-ant-1.8.ant.conf
Source1000:     pre_checkin.sh
Source1001:     http://www.apache.org/dist/ant/source/apache-ant-%{version}-src.tar.bz2.asc
Source1002:     ant.keyring
Patch0:         apache-ant-no-test-jar.patch
Patch1:         apache-ant-class-path-in-manifest.patch
#PATCH-FIX-SLE: fix building with old gcj by working around bugs
Patch2:         apache-ant-old-gcj-build.patch
%if %{with bootstrap}
BuildRequires:  java-1_5_0-gcj-compat-devel
#!BuildIgnore:  java-1_6_0-openjdk java-1_6_0-openjdk-devel
#!BuildIgnore:  java-1_7_0-openjdk java-1_7_0-openjdk-devel
%else
BuildRequires:  java-devel >= 1.5.0
%endif
BuildRequires:  antlr-bootstrap
BuildRequires:  javapackages-tools
BuildRequires:  unzip
#BuildRequires:  xerces-j2-bootstrap
#!BuildIgnore: xerces-j2-bootstrap
BuildRequires:  xml-commons-apis-bootstrap
%if %{with junit} || %{with antlr}
BuildRequires:  ant = %{version}
BuildRequires:  junit
#!BuildIgnore:  antlr
%endif
%if %{with antlr}
BuildRequires:  xerces-j2
BuildRequires:  xml-commons-apis
%endif
%if %{with bootstrap}
Requires:       java-devel >= 1.5.0
Requires:       javapackages-tools
Requires:       jaxp_parser_impl
Requires:       xml-commons-apis
Requires:       xml-commons-resolver
Obsoletes:      apache-ant < %{version}
Provides:       apache-ant = %{version}
Obsoletes:      ant-nodeps < %{version}
Provides:       ant-nodeps = %{version}
Obsoletes:      ant-trax < %{version}
Provides:       ant-trax = %{version}
%endif
%if %{with antlr}
Requires:       antlr
%requires_eq    ant
Provides:       ant-antlr = %{version}-%{release}
%endif
%if %{with junit}
Requires:       junit4
%requires_eq    ant
%endif
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%if %{with junit}
%description
Apache Ant is a Java-based build tool.

This package contains optional JUnit tasks for Apache Ant.
%else
# FIXME: this should be different for antlr
%description
Apache Ant is a Java-based build tool. In theory, it is kind of like
Make, but without Make's wrinkles.

Why another build tool when there is already make, gnumake, nmake, jam,
and others? Because all those tools have limitations that Ant's
original author could not live with when developing software across
multiple platforms. Make-like tools are inherently shell-based--they
evaluate a set of dependencies then execute commands, not unlike what
you would issue in a shell. This means that you can easily extend these
tools by using or writing any program for the OS that you are working
on. However, this also means that you limit yourself to the OS, or at
least the OS type, such as Unix, that you are working on.

Makefiles are inherently evil as well. Anybody who has worked on them
for any time has run into the dreaded tab problem. "Is my command not
executing because I have a space in front of my tab???" said the
original author of Ant way too many times. Tools like Jam took care of
this to a great degree, but still have yet another format to use and
remember.

Ant is different. Instead of a model where it is extended with
shell-based commands, Ant is extended using Java classes. Instead of
writing shell commands, the configuration files are XML-based, calling
out a target tree where various tasks are executed. Each task is run by
an object that implements a particular task interface.

Granted, this removes some of the expressive power that is inherent by
being able to construct a shell command such as `find . -name foo -exec
rm {}`, but it gives you the ability to be cross-platform--to work
anywhere and everywhere. If you really need to execute a shell command,
Ant has an <exec> task that allows different commands to be executed
based on the OS used.

%endif

%if %{with bootstrap}
%package -n ant-jmf
Summary:        Optional jmf tasks for ant
License:        Apache-2.0
Group:          Development/Tools/Building
Requires:       ant = %{version}
Provides:       ant-jmf = %{version}-%{release}

%description -n ant-jmf
Apache Ant is a Java-based build tool.

This package contains optional jmf tasks for Apache Ant.

%package -n ant-swing
Summary:        Optional swing tasks for ant
License:        Apache-2.0
Group:          Development/Tools/Building
Requires:       ant = %{version}
Provides:       ant-swing = %{version}-%{release}

%description -n ant-swing
Apache Ant is a Java-based build tool.

This package contains optional swing tasks for Apache Ant.

%package -n ant-scripts
Summary:        Additional scripts for ant
License:        Apache-2.0
Group:          Development/Tools/Building
Requires:       %{_bindir}/perl
Requires:       %{_bindir}/python
Requires:       ant = %{version}

%description -n ant-scripts
Apache Ant is a Java-based build tool.

This package contains additional perl and python scripts for Apache
Ant.

%endif #if bootstrap

%if %{with antlr}

%package -n ant-apache-bsf
Summary:        Optional apache bsf tasks for ant
License:        Apache-2.0
Group:          Development/Tools/Building
Requires:       bsf
%requires_eq    ant
BuildRequires:  bsf

%description -n ant-apache-bsf
Apache Ant is a Java-based build tool.

This package contains optional apache bsf tasks for Apache Ant.

%package -n ant-apache-resolver
Summary:        Optional apache resolver tasks for ant
License:        Apache-2.0
Group:          Development/Tools/Building
Requires:       xml-commons-resolver
%requires_eq    ant
BuildRequires:  xml-commons-resolver

%description -n ant-apache-resolver
Apache Ant is a Java-based build tool.

This package contains optional apache resolver tasks for Apache Ant.

%package -n ant-commons-logging
Summary:        Optional commons logging tasks for ant
License:        Apache-2.0
Group:          Development/Tools/Building
Requires:       jakarta-commons-logging
%requires_eq    ant
BuildRequires:  jakarta-commons-logging

%description -n ant-commons-logging
Apache Ant is a Java-based build tool.

This package contains optional commons logging tasks for Apache Ant.

%package -n ant-commons-net
Summary:        Optional commons net tasks for ant
License:        Apache-2.0
Group:          Development/Tools/Building
Requires:       jakarta-commons-net
%requires_eq    ant
BuildRequires:  jakarta-commons-net

%description -n ant-commons-net
Apache Ant is a Java-based build tool.

This package contains optional commons net tasks for Apache Ant.

# Disable because we don't ship the dependencies
%if 0
%package -n ant-jai
Summary:        Optional jai tasks for ant
License:        Apache-2.0
Group:          Development/Tools/Building
Requires:       jai
%requires_eq    ant
BuildRequires:  jai

%description -n ant-jai
Optional jai tasks for ant.
%endif

%package -n ant-apache-bcel
Summary:        Optional apache bcel tasks for ant
License:        Apache-2.0
Group:          Development/Tools/Building
Requires:       bcel
%requires_eq    ant
BuildRequires:  bcel
Provides:       ant-jakarta-bcel = %{version}
Obsoletes:      ant-jakarta-bcel < %{version}

%description -n ant-apache-bcel
Apache Ant is a Java-based build tool.

This package contains optional apache bcel tasks for Apache Ant.

%package -n ant-apache-log4j
Summary:        Optional apache log4j tasks for ant
License:        Apache-2.0
Group:          Development/Tools/Building
Requires:       log4j
%requires_eq    ant
BuildRequires:  log4j-mini
Provides:       ant-jakarta-log4j = %{version}
Obsoletes:      ant-jakarta-log4j < %{version}

%description -n ant-apache-log4j
Apache Ant is a Java-based build tool.

This package contains optional apache log4j tasks for Apache Ant.

%package -n ant-apache-oro
Summary:        Optional apache oro tasks for ant
License:        Apache-2.0
Group:          Development/Tools/Building
Requires:       oro
%requires_eq    ant
BuildRequires:  oro
Provides:       ant-jakarta-oro = %{version}
Obsoletes:      ant-jakarta-oro < %{version}

%description -n ant-apache-oro
Apache Ant is a Java-based build tool.

This package contains optional apache oro tasks for Apache Ant.

%package -n ant-apache-regexp
Summary:        Optional apache regexp tasks for ant
License:        Apache-2.0
Group:          Development/Tools/Building
Requires:       regexp
%requires_eq    ant
BuildRequires:  regexp
Provides:       ant-jakarta-regexp = %{version}
Obsoletes:      ant-jakarta-regexp < %{version}

%description -n ant-apache-regexp
Apache Ant is a Java-based build tool.

This package contains optional apache regexp tasks for Apache Ant.

%package -n ant-apache-xalan2
Summary:        Optional apache xalan2 tasks for ant
License:        Apache-2.0
Group:          Development/Tools/Building
BuildRequires:  regexp
BuildRequires:  xalan-j2
Requires:       regexp
%requires_eq    ant

%description -n ant-apache-xalan2
Optional apache xalan2 tasks for %{name}.

%package -n ant-javamail
Summary:        Optional javamail tasks for ant
License:        CDDL-1.0
Group:          Development/Tools/Building
BuildRequires:  javamail >= 1.2-5jpp
Requires:       javamail >= 1.2-5jpp
%requires_eq    ant

%description -n ant-javamail
Apache Ant is a Java-based build tool.

This package contains optional javamail tasks for Apache Ant.

%package -n ant-jdepend
Summary:        Optional jdepend tasks for ant
License:        Apache-2.0
Group:          Development/Tools/Building
Requires:       jdepend
%requires_eq    ant
BuildRequires:  jdepend

%description -n ant-jdepend
Apache Ant is a Java-based build tool.

This package contains optional jdepend tasks for Apache Ant.

%package -n ant-jsch
Summary:        Optional jsch tasks for ant
License:        Apache-2.0
Group:          Development/Tools/Building
Requires:       jsch
%requires_eq    ant
BuildRequires:  jsch

%description -n ant-jsch
Apache Ant is a Java-based build tool.

This package contains optional jsch tasks for Apache Ant.

%package -n ant-testutil
Summary:        Test utility classes for ant
License:        Apache-2.0
Group:          Development/Tools/Building
Requires:       junit4
%requires_eq    ant

%description -n ant-testutil
Test utility tasks for %{name}.

%package -n ant-manual
Summary:        Manual for ant
License:        Apache-2.0
Group:          Development/Tools/Building

%description -n ant-manual
Apache Ant is a Java-based build tool.

This package contains the manual for Apache Ant.

%if 0%{?build_javadoc}
%package -n ant-javadoc
Summary:        Javadoc for ant
License:        Apache-2.0
Group:          Development/Tools/Building

%description -n ant-javadoc
Apache Ant is a Java-based build tool.

This package contains the javadoc documentation for Apache Ant.
%endif #javadoc
%endif

%prep
%setup -q -n apache-ant-%{version}
#Fixup version
find -name build.xml -o -name pom.xml | xargs sed -i -e s/-SNAPSHOT//

# When bootstrapping, we don't have junit
%if %{with bootstrap}
%patch0 -p1
%if 0%{?suse_version} < 1200
%patch2 -p1
%endif
%endif

# Fix class-path-in-manifest rpmlint warning
%patch1

# clean jar files
%{_bindir}/find . -name "*.jar" | %{_bindir}/xargs -t rm

# failing testcases. TODO see why
rm src/tests/junit/org/apache/tools/ant/types/selectors/SignedSelectorTest.java \
   src/tests/junit/org/apache/tools/ant/taskdefs/condition/IsFileSelectedTest.java \
   src/tests/junit/org/apache/tools/ant/taskdefs/condition/IsSignedTest.java \
   src/tests/junit/org/apache/tools/ant/taskdefs/JarTest.java \
   src/tests/junit/org/apache/tools/mail/MailMessageTest.java

#FIXME: need newer junit4 package
#rm src/tests/junit/org/example/junit/JUnit4Skippable.java

#install jars
%if %{with junit}
build-jar-repository -s -p lib/optional junit4
%endif
%if %{with antlr}
# we need to build junit in antlr, but we remove it later
build-jar-repository -s -p lib/optional xerces-j2 xml-commons-jaxp-1.3-apis antlr-bootstrap bcel javamail/mailapi jdepend junit4 log4j oro regexp bsf commons-logging commons-net jsch xalan-j2 xml-commons-resolver
%endif

# Fix file-not-utf8 rpmlint warning
iconv KEYS -f iso-8859-1 -t utf-8 -o KEYS.utf8
mv KEYS.utf8 KEYS
iconv LICENSE -f iso-8859-1 -t utf-8 -o LICENSE.utf8
mv LICENSE.utf8 LICENSE
# -----------------------------------------------------------------------------

%build
export OPT_JAR_LIST=:

%if %{with antlr} || %{with junit}
ant -Dbuild.sysclasspath=first jars test-jar

#remove empty jai and netrexx jars. Due to missing dependencies they contain only manifests.
rm -rf build/lib/ant-jai.jar build/lib/ant-netrexx.jar

%if 0%{?build_javadoc}
export CLASSPATH=$(build-classpath xerces-j2 xml-commons-jaxp-1.3-apis antlr bcel jaf javamail/mailapi jdepend junit4 log4j oro regexp bsf commons-logging commons-net jsch xalan-j2 xml-commons-resolver)
ant javadocs
%endif

%endif

%if %{with bootstrap}
export GC_MAXIMUM_HEAP_SIZE="134217728" #128M
export JAVA_HOME=%{java_home}
export CLASSPATH=$JAVA_HOME/lib/tools.jar
export BOOTJAVAC_OPTS="-C -Wno-deprecated"
sh -x ./build.sh --noconfig jars

%endif

%install
# ANT_HOME and subdirs
mkdir -p %{buildroot}%{ant_home}/{lib,etc}
# jars
install -d -m 755 %{buildroot}%{_javadir}/ant
install -d -m 755 %{buildroot}%{_mavenpomdir}

%if ! %{with junit}
rm build/lib/ant-junit*.jar
%else
# remove all others
for i in build/lib/ant-*.jar ; do
  case $i in
   */ant-junit*) 
     ;;
   *)
     rm -v $i
     ;;
  esac
done
%endif 

for jar in build/lib/*.jar
do
  jarname=$(basename $jar .jar)
  pomname="JPP.ant-${jarname}.pom"

  #Determine where to put it
  case $jarname in
#These go into %%{_javadir}, pom files have different names
  ant | ant-bootstrap | ant-launcher)
%if %{with bootstrap}
  destdir=%{buildroot}%{_javadir}; destname="";pomname="JPP-$jarname.pom"
%else
  continue
%endif
  ;;
  ant-jmf|ant-swing)
%if %{with bootstrap}
  destdir=%{buildroot}%{_javadir}/ant; destname="ant/";
%else
  continue
%endif
  ;;
#Bootstracp builds an incomplete ant-foo jars, don't ship them
  *)
%if %{with bootstrap}
  continue
%else
#These go into %%{_javadir}/ant
  destdir=%{buildroot}%{_javadir}/ant; destname="ant/";
%endif
  ;;
  esac

  #instal jar
  install -m 644 ${jar} ${destdir}/${jarname}.jar
  # jar aliases
  ln -sf ../../java/${destname}${jarname}.jar %{buildroot}%{ant_home}/lib/${jarname}.jar

  #bootstrap does not have a pom
  [ $jarname == ant-bootstrap ] && continue

  #install pom
  install -m 644 src/etc/poms/${jarname}/pom.xml %{buildroot}/%{_mavenpomdir}/${pomname}
  echo %%add_maven_depmap "${pomname}" "${destname}${jarname}.jar"
  %add_maven_depmap ${pomname} ${destname}${jarname}.jar
done

%if %{with bootstrap}
#ant-parent pom
install -m 644 src/etc/poms/pom.xml %{buildroot}/%{_mavenpomdir}/JPP-ant-parent.pom
%add_maven_depmap JPP-ant-parent.pom

# scripts: remove dos and os/2 scripts
rm -f src/script/*.bat
rm -f src/script/*.cmd

# XSLs
cp -p src/etc/*.xsl %{buildroot}%{ant_home}/etc
rm -f  %{buildroot}%{ant_home}/etc/{maudit-frames,jdepend,jdepend-frames,junit-frames,junit-noframes}.xsl
%endif
%if %{with junit}
cp -p src/etc/{junit-noframes,junit-frames}.xsl %{buildroot}%{ant_home}/etc
%endif
%if %{with antlr}
cp -p src/etc/{maudit-frames,jdepend,jdepend-frames}.xsl %{buildroot}%{ant_home}/etc
%endif

%if %{with bootstrap}
# install everything else
mkdir -p %{buildroot}%{_bindir}
cp -p src/script/* %{buildroot}%{_bindir}/
mkdir -p %{buildroot}%{_datadir}/%{name}/bin/
ln -sf %{_bindir}/antRun %{buildroot}/%{_datadir}/%{name}/bin/antRun
%endif

mkdir -p %{buildroot}%{_sysconfdir}/ant.d

%if %{with bootstrap}
# default ant.conf
mkdir -p %{buildroot}%{_sysconfdir}
cp -p %{SOURCE1} %{buildroot}%{_sysconfdir}/ant.conf

# OPT_JAR_LIST fragments
echo "ant/ant-jmf" > %{buildroot}%{_sysconfdir}/%{name}.d/jmf
echo "ant/ant-swing" > %{buildroot}%{_sysconfdir}/%{name}.d/swing
%endif

%if %{with junit}
echo "junit ant/ant-junit" > %{buildroot}%{_sysconfdir}/ant.d/junit
%endif

%if %{with antlr}
echo "antlr ant/ant-antlr" > %{buildroot}%{_sysconfdir}/ant.d/antlr
echo "bsf ant/ant-apache-bsf" > %{buildroot}%{_sysconfdir}/ant.d/apache-bsf
echo "xml-commons-resolver ant/ant-apache-resolver" > %{buildroot}%{_sysconfdir}/ant.d/apache-resolver
echo "jakarta-commons-logging ant/ant-commons-logging" > %{buildroot}%{_sysconfdir}/ant.d/commons-logging
echo "jakarta-commons-net ant/ant-commons-net" > %{buildroot}%{_sysconfdir}/ant.d/commons-net
#echo "jai ant/ant-jai" > %{buildroot}%{_sysconfdir}/ant.d/jai
echo "bcel ant/ant-apache-bcel" > %{buildroot}%{_sysconfdir}/ant.d/apache-bcel
echo "log4j ant/ant-apache-log4j" > %{buildroot}%{_sysconfdir}/ant.d/apache-log4j
echo "oro ant/ant-apache-oro" > %{buildroot}%{_sysconfdir}/ant.d/apache-oro
echo "regexp ant/ant-apache-regexp" > %{buildroot}%{_sysconfdir}/ant.d/apache-regexp
echo "xalan-j2 ant/ant-apache-xalan2" > %{buildroot}%{_sysconfdir}/ant.d/apache-xalan2
echo "javamail jaf ant/ant-javamail" > %{buildroot}%{_sysconfdir}/ant.d/javamail
echo "jdepend ant/ant-jdepend" > %{buildroot}%{_sysconfdir}/ant.d/jdepend
echo "jsch ant/ant-jsch" > %{buildroot}%{_sysconfdir}/ant.d/jsch
echo "testutil ant/ant-testutil" > %{buildroot}%{_sysconfdir}/ant.d/testutil
%endif

%if %{with antlr}

%if 0%{?build_javadoc}
mkdir -p %{buildroot}%{_javadocdir}/ant
cp -pr build/javadocs/* %{buildroot}%{_javadocdir}/ant
%endif #javadoc

%endif

%if 0%{?build_javadoc}
# fix link between manual and javadoc
(cd manual; ln -sf %{_javadocdir}/%{name} api)
%endif #javadoc

%if %{with bootstrap}
find %{buildroot}%{_datadir}/ant/etc -type f -name "*.xsl" \
                                                 -a ! -name ant-update.xsl \
                                                 -a ! -name changelog.xsl \
                                                 -a ! -name coverage-frames.xsl \
                                                 -a ! -name junit-frames-xalan1.xsl \
                                                 -a ! -name log.xsl \
                                                 -a ! -name mmetrics-frames.xsl \
                                                 -a ! -name tagdiff.xsl \
                                                 | xargs -t rm
%endif

%if %{with bootstrap}

%files
%defattr(0644,root,root,0755)
%doc KEYS LICENSE NOTICE README WHATSNEW
%config(noreplace) %{_sysconfdir}/%{name}.conf
%attr(0755,root,root) %{_bindir}/ant
%attr(0755,root,root) %{_bindir}/antRun
%{_javadir}/%{name}.jar
%{_javadir}/%{name}-launcher.jar
%{_javadir}/%{name}-bootstrap.jar
%dir %{_javadir}/%{name}
%dir %{ant_home}
%dir %{ant_home}/etc
%{ant_home}/bin
%{ant_home}/etc/ant-update.xsl
%{ant_home}/etc/changelog.xsl
%{ant_home}/etc/coverage-frames.xsl
%{ant_home}/etc/mmetrics-frames.xsl
%{ant_home}/etc/log.xsl
%{ant_home}/etc/tagdiff.xsl
%{ant_home}/etc/junit-frames-xalan1.xsl
# % {ant_home}/etc/common2master.xsl
# % {ant_home}/etc/printFailingTests.xsl
%dir %{ant_home}/lib
%dir %{_sysconfdir}/%{name}.d
%{ant_home}/lib/ant.jar
%{ant_home}/lib/ant-bootstrap.jar
%{ant_home}/lib/ant-launcher.jar
%dir %{_sysconfdir}/ant.d
%{_mavenpomdir}/JPP-ant-launcher.pom
%{_mavenpomdir}/JPP-ant-parent.pom
%{_mavenpomdir}/JPP-ant.pom
%config(noreplace) %{_mavendepmapfragdir}/*
%dir %{_mavenpomdir}

%endif

%if %{with antlr}
%files
%defattr(0644,root,root,0755)
%{_javadir}/ant/ant-antlr.jar
%{ant_home}/lib/ant-antlr.jar
%config(noreplace) %{_sysconfdir}/ant.d/antlr
%{_mavenpomdir}/JPP.ant-ant-antlr.pom
%config %{_mavendepmapfragdir}/ant-antlr
%dir %{_mavenpomdir}
%endif

%if %{with junit}
%files
%defattr(0644,root,root,0755)
%{_javadir}/ant/ant-junit*.jar
%{ant_home}/lib/ant-junit*.jar
%config(noreplace) %{_sysconfdir}/ant.d/junit
%config(noreplace) %{_mavendepmapfragdir}/ant-junit
%{ant_home}/etc/junit-frames.xsl
%{ant_home}/etc/junit-noframes.xsl
%{_mavenpomdir}/JPP.ant-ant-junit*.pom
%dir %{_mavenpomdir}
%endif

### Basic ant subpackages
%if %{with bootstrap}

%files -n ant-jmf
%defattr(0644,root,root,0755)
%{_javadir}/ant/ant-jmf.jar
%{ant_home}/lib/ant-jmf.jar
%config(noreplace) %{_sysconfdir}/ant.d/jmf
%{_mavenpomdir}/JPP.ant-ant-jmf.pom

%files -n ant-swing
%defattr(0644,root,root,0755)
%{_javadir}/ant/ant-swing.jar
%{ant_home}/lib/ant-swing.jar
%config(noreplace) %{_sysconfdir}/ant.d/swing
%{_mavenpomdir}/JPP.ant-ant-swing.pom
%dir %{_mavenpomdir}

%files -n ant-scripts
%defattr(0755,root,root,0755)
%{_bindir}/*.pl
%{_bindir}/*.py*
%endif #if bootstrap

%if %{with antlr}

%files -n ant-apache-bsf
%defattr(0644,root,root,0755)
%{_javadir}/ant/ant-apache-bsf.jar
%{ant_home}/lib/ant-apache-bsf.jar
%config(noreplace) %{_sysconfdir}/ant.d/apache-bsf
%{_mavenpomdir}/JPP.ant-ant-apache-bsf.pom
%dir %{_mavenpomdir}

%files -n ant-apache-resolver
%defattr(0644,root,root,0755)
%{_javadir}/ant/ant-apache-resolver.jar
%{ant_home}/lib/ant-apache-resolver.jar
%config(noreplace) %{_sysconfdir}/ant.d/apache-resolver
%{_mavenpomdir}/JPP.ant-ant-apache-resolver.pom
%dir %{_mavenpomdir}

%files -n ant-commons-logging
%defattr(0644,root,root,0755)
%{_javadir}/ant/ant-commons-logging.jar
%{ant_home}/lib/ant-commons-logging.jar
%config(noreplace) %{_sysconfdir}/ant.d/commons-logging
%{_mavenpomdir}/JPP.ant-ant-commons-logging.pom
%dir %{_mavenpomdir}

%files -n ant-commons-net
%defattr(0644,root,root,0755)
%{_javadir}/ant/ant-commons-net.jar
%{ant_home}/lib/ant-commons-net.jar
%config(noreplace) %{_sysconfdir}/ant.d/commons-net
%{_mavenpomdir}/JPP.ant-ant-commons-net.pom
%dir %{_mavenpomdir}
# Disable as we dont ship the dependencies
%if 0

%files -n ant-jai
%defattr(0644,root,root,0755)
%{_javadir}/ant/ant-jai.jar
%{ant_home}/lib/ant-jai.jar
%config(noreplace) %{_sysconfdir}/ant.d/jai
%endif

%files -n ant-apache-bcel
%defattr(0644,root,root,0755)
%{_javadir}/ant/ant-apache-bcel.jar
%{ant_home}/lib/ant-apache-bcel.jar
%config(noreplace) %{_sysconfdir}/ant.d/apache-bcel
%{_mavenpomdir}/JPP.ant-ant-apache-bcel.pom
%dir %{_mavenpomdir}

%files -n ant-apache-log4j
%defattr(0644,root,root,0755)
%{_javadir}/ant/ant-apache-log4j.jar
%{ant_home}/lib/ant-apache-log4j.jar
%config(noreplace) %{_sysconfdir}/ant.d/apache-log4j
%{_mavenpomdir}/JPP.ant-ant-apache-log4j.pom
%dir %{_mavenpomdir}

%files -n ant-apache-oro
%defattr(0644,root,root,0755)
%{_javadir}/ant/ant-apache-oro.jar
%{ant_home}/lib/ant-apache-oro.jar
%{ant_home}/etc/maudit-frames.xsl
%config(noreplace) %{_sysconfdir}/ant.d/apache-oro
%{_mavenpomdir}/JPP.ant-ant-apache-oro.pom
%dir %{_mavenpomdir}

%files -n ant-apache-regexp
%defattr(-,root,root,-)
%{_javadir}/ant/ant-apache-regexp.jar
%{ant_home}/lib/ant-apache-regexp.jar
%config(noreplace) %{_sysconfdir}/ant.d/apache-regexp
%{_mavenpomdir}/JPP.ant-ant-apache-regexp.pom
%dir %{_mavenpomdir}

%files -n ant-apache-xalan2
%defattr(-,root,root,-)
%{_javadir}/ant/ant-apache-xalan2.jar
%{ant_home}/lib/ant-apache-xalan2.jar
%config(noreplace) %{_sysconfdir}/ant.d/apache-xalan2
%{_mavenpomdir}/JPP.ant-ant-apache-xalan2.pom
%dir %{_mavenpomdir}

%files -n ant-javamail
%defattr(0644,root,root,0755)
%{_javadir}/ant/ant-javamail.jar
%{ant_home}/lib/ant-javamail.jar
%config(noreplace) %{_sysconfdir}/ant.d/javamail
%{_mavenpomdir}/JPP.ant-ant-javamail.pom
%dir %{_mavenpomdir}

%files -n ant-jdepend
%defattr(0644,root,root,0755)
%{_javadir}/ant/ant-jdepend.jar
%{ant_home}/lib/ant-jdepend.jar
%config(noreplace) %{_sysconfdir}/ant.d/jdepend
%{ant_home}/etc/jdepend.xsl
%{ant_home}/etc/jdepend-frames.xsl
%{_mavenpomdir}/JPP.ant-ant-jdepend.pom
%dir %{_mavenpomdir}

%files -n ant-jsch
%defattr(0644,root,root,0755)
%{_javadir}/ant/ant-jsch.jar
%{ant_home}/lib/ant-jsch.jar
%config(noreplace) %{_sysconfdir}/ant.d/jsch
%{_mavenpomdir}/JPP.ant-ant-jsch.pom
%dir %{_mavenpomdir}

%files -n ant-testutil
%defattr(-,root,root,-)
%{_javadir}/ant/ant-testutil.jar
%{ant_home}/lib/ant-testutil.jar
%config(noreplace) %{_sysconfdir}/ant.d/testutil
%{_mavenpomdir}/JPP.ant-ant-testutil.pom
%dir %{_mavenpomdir}

%files -n ant-manual
%defattr(0644,root,root,0755)
%doc manual/*

%if 0%{?build_javadoc}

%files -n ant-javadoc
%defattr(0644,root,root,0755)
%{_javadocdir}/ant
%endif #javadoc
%endif

%changelog
* Thu Aug 28 2014 coolo@suse.com
- to bootstrap 13.2 we need another split because bsf depends on things
  that depend on junit and as antlr requires bsf, we need a 3rd step ->
  split ant-junit to build in between ant and ant-antlr
* Fri Jul  4 2014 tchvatal@suse.com
- Fix building on SLE.
- Added patch:
  * apache-ant-old-gcj-build.patch
* Fri Jul  4 2014 tchvatal@suse.com
- Update to 1.9.4:
  * Read WHATSNEW file for full changelist
  * initial support for Java 1.9
  * <junit> has now a threads attribute allowing to run the tests in
    several threads. Bugzilla Report 55925
  * TarInputStream will now read archives created by tar
    implementations that encode big numbers by not adding a trailing
    NUL.
* Thu May 15 2014 peter.trommler@ohm-hochschule.de
- fix summary (was antlr summary)
* Mon May 12 2014 darin@darins.net
- SLE_11 specific spec files for ant/ant-antlr. These build with
  openjdk, which introduced bootstrap breakage in Factory.
- Update pre_checkin.sh for SLE_11 specific spec's
* Fri May  2 2014 tchvatal@suse.com
- Revert the bootstrap breakage.
* Thu Apr 24 2014 dmueller@suse.com
- remove dependency on gpg-offline (blocks rebuilds and
  tarball integrity is checked by source-validator anyway, plus
  it was commented out)
- remove apache-ant-bz163689.patch (was not applied anywhere)
* Wed Apr 23 2014 darin@darins.net
- Update packaging to build the openjdk and not gcj
* Thu Jan  2 2014 mvyskocil@suse.com
- Update to 1.9.3
- BugFixes:
  * Ant 1.8 exec task changes have slowed exec to a crawl, apache#54128
  * <parallel> swallowed the status code of nested <fail> tasks,
  apache#55539
  * a race condition could make <fixcrlf> tasks of parallel builds to
    interfere with each other, apache#54393
  * <mail>'s mailport still didn't work properly when using smtps,
  apache#49267
  * using attributes belonging to the if and unless namespaces
  made macrodef fail, apache#55885.
  * Apt is not available under JDK 1.8, apache#55922
- drop unused macros
- add gpg verification
* Wed Dec  4 2013 mvyskocil@suse.com
- use requires_eq instead of manual call of rpm -q
* Wed Oct  2 2013 mvyskocil@suse.com
- install compat symlink to /usr/share/ant/bin/antRun to make scala build
* Mon Sep  9 2013 tchvatal@suse.com
- Move from jpackage-utils to javapackage-tools
* Thu Aug 22 2013 mvyskocil@suse.com
- Update to 1.9.2
- Incompatible changes:
  * ProjectHelper's implementation import and include tasks
  defaults the targetPrefix to ProjectHelper.USE_PROJECT_NAME_AS_TARGET_PREFIX.
  ProjectHelper2 is not affected, apache#54940.
  * FixCRLF used to treat the EOL value ASIS to convert to the system property
  line.separator. Specified was that ASIS would leave the EOL characters alone,
  the task now really leaves the EOL characters alone. This also implies that
  EOL ASIS will not insert a newline even if fixlast is set to true.
  apache#53036
  * The CommandLauncher hierarchy that used to be a set of inner
  classes of Execute has been extracted to the
  org.apache.tools.ant.taskdefs.launcher package.
  * Any FileResource whose represented File has a parent also has a basedir.
  * Removing the Perforce Ant tasks replaced by tasks supplied by Perforce Inc.
  * Setting the default encoding of StringResource to UTF-8 instead of null
- Bugfixes:
  * <javadoc> post-process generated docs to migitiate frame
    injection attack (CVE-2013-1571) apache#55132
  * Parsing of zip64 extra fields has become more lenient
  * TarInputStream should now properly read GNU longlink entries' names.
  apache#55040.
  * <java> and <exec> used to be too restrictive when evaluating
  whether a given set of options is compatible with spawning the new
  process, apache#55112.
  * Corrected XSLTC error in <junitreport>, apache#54641.
  * and many more, see WHATSNEW for details
* Mon Jan  7 2013 mvyskocil@suse.com
- remove xerces-j2-bootstrap depenency (bnc#789163)
* Wed May 30 2012 cfarrell@suse.com
- license update: CDDL-1.0
  SPDX format (note that it should CDDL-1.1 if the (c) owner and license
  steward is Oracle)
* Tue May 15 2012 mvyskocil@suse.cz
- build ignore java-1_7_0-openjdk as well
* Wed Feb  1 2012 mvyskocil@suse.cz
- revert the Recommends to fix a lot of build fails
* Wed Jan 25 2012 mvyskocil@suse.cz
- use new _mavendepmapfragdir macro instead of hardocded path
- change java-devel Requires to Recommends
* Tue Jan  3 2012 dmueller@suse.de
- use dist-lite and dist_javadocs to make javadoc build really
  optional
- fix arm check (ifarch does not work in a noarch spec file)
* Thu Dec 15 2011 mvyskocil@suse.cz
- use dist and javadocs targets to make javadoc build really configurable
- disable javadoc build on arm to speedup the build of java platform
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
* Mon Mar 14 2011 mvyskocil@suse.cz
- ignore openjdk for build of core ant
* Wed Mar  9 2011 mvyskocil@suse.cz
- Update to ant 1.8.2
  * performance improvements in directory scanning
  * XSLT task honors classpath again (bugrep 49271)
  * distinction between core tasks and optional tasks is abolished
  * new task augment allows to add attributes or nested elements to previously
    defined references
  * Lexically scoped local properties, i.e. properties that are only defined
    inside a target, sequential block or similar environment. This is very
    useful inside of <macrodef>s where a macro can now define a temporary
    property that will disappear once the task has finished.
  * <import> can now import from any file- or URL-providing resource - this
    includes <javaresource>. This means <import> can read build file snippets
    from JARs or fixed server URLs. There are several other improvements in the
    area of import.
  * Various improvements to the directory scanning code that help with symbolic
    link cycles (as can be found on MacOS X Java installations for example) and
    improve scanning performance. For big directory trees the improvement is
    dramatic.
  * The way developers can extend Ant's property expansion algorithm has been
    rewritten (breaking the older API) to be easier to use and be more
    powerful. The whole local properties mechanism is implemented using that
    API and could be implemented in a separate library without changes in Ant's
    core. Things like the yet-to-be-released props Antlib can now provide often
    required "scripty" fuctions without touching Ant itself. At the same time
    the if and unless attributes have been rewritten to do the expected thing
    if applied to a property expansion (i.e. if="${foo}" will mean "yes, do it"
    if ${foo} expands to true, in Ant 1.7.1 it would mean "no" unless a
    property named "true" existed). This adds "testing conditions" as a new
    use-case to property expansion.
  * A new top-level element <extension-point> assists in writing re-usable
    build files that are meant to be imported. <extension-point> has a name and
    a dependency-list like <target> and can be used like a <target> from the
    command line or a dependency-list but the importing build file can add
    targets to the <extension-point>'s depends list.
  * Ant now requires Java 1.4 or later new task include provides an alternative
  to <import> that should be preferred when you don't want to override any
  targets
  * numerous bug fixes and improvements as documented in
    Bugzilla and in WHATSNEW
- merge the nodeps and trax packages to main one
- build ant-antlr.spec using openjdk
- add ant-apache-xalan2 and ant-testutil
- remove all pom files, as they are included and build from source tarball
* Fri Apr  9 2010 mvyskocil@suse.cz
- fix bnc#595144 - Compiled binary in ant
  remove test.exe from source tarball
* Thu Mar 18 2010 mvyskocil@suse.cz
- fix the compat symlinks
* Wed Mar 17 2010 mvyskocil@suse.cz
- return back the /usr/share/ant/lib compat symlinks
  http://lists.opensuse.org/opensuse-java/2010-03/msg00007.html
* Wed Jun 17 2009 mvyskocil@suse.cz
- do not use Release number in Requires of subpackages
* Sun May  3 2009 ro@suse.de
- do not assume release number for ant and ant-antlr are identical
* Tue Apr 28 2009 mvyskocil@suse.cz
- update to 1.7.1. Upstream changes (full list is in WHATSNEW):
  * String resources only have properties single expanded. If you relied on
  <string> resources being expanded more than once, it no longer happens.
  Bugzilla report 42277.
  * A String resource's encoding attribute was only taken into account when
  set from the resource's OutputStream; the InputStream provided the String's
  binary content according to the platform's default encoding. Behavior has
  been modified to encode outgoing (InputStream) content as well as encoding
  incoming (OutputStream) content.
  * <java> with fork now returns gives -1 instead of 0 as result when
  * failonerror
  is false and some exception (including timeout) occurs. Br 42377.
  * ant-type attribute has been marked as deprecated and a warning has been
  issued if it is encountered in the build file.
  * FileUtils.createTempFile now actually creates the file.
  The TempFile task still does not create the file by default, can be
  instructed to do so however using a new parameter.  Bugzilla report 33969.
- added maven pom files from jpackage project
- synchronized ant.spec with jpackage.org 5.0
- used ant-antlr-prepare.sh for generate of ant-antlr.spec from ant.spec to
  keep them synchronized. Build is branched using value of %%%%bootstrap macro:
  * bootstrap == 1 means build ant, ant-{jmf,nodeps,scripts,swing,trax}
  * bootstrap == 0 means build rest of ant modules + ant-javadoc
* Mon Nov  3 2008 mvyskocil@suse.cz
- [bnc#440645] - ant fails without installed jdk:
  - added a java-devel to Recommends:
* Mon Jul 21 2008 ro@suse.de
- use xerces-j2-bootstrap to build (as early as possible)
- add java doc dir to filelist of javadoc subpackage to fix build
* Wed Jul 16 2008 coolo@suse.de
- avoid another build cycle
* Wed May  7 2008 mvyskocil@suse.cz
- build using gcj, to allow a openjdk6 bootstrap
- change a source and a target level to 1.5 in build.xml
* Tue Aug 14 2007 skh@suse.de
- disable junit tests and remove junit from BuildRequires to break
  circular build dependency
* Fri Jul  6 2007 dbornkessel@suse.de
- update to version 1.7.0
  major changes are (for a complete list, consult /usr/share/doc/packages/ant/WHATSNEW):
  Changes that could break older environments:
  - ------------------------------------------
  * Initial support for JDK 6 (JSR 223) scripting.
  <*script*> tasks will now use javax.scripting if BSF is
  not available, or if explicitly requested by using
  a "manager" attribute.
  * The -noproxy option which was in the previous 1.7 alpha and beta
  releases has been removed. It is the default behavior and not needed.
  * Removed launcher classes from nodeps jar.
  * <classconstants> filter reader uses ISO-8859-1 encoding to read
  the java class file. Bugzilla report 33604.
  * Defer reference process. Bugzilla 36955, 34458, 37688.
  This may break build files in which a reference was set in a target which was
  never executed. Historically, Ant would set the reference early on, during parse
  time, so the datatype would be defined. Now it requires the reference to have
  been in a bit of the build file which was actually executed. If you get
  an error about an undefined reference, locate the reference and move it somewhere
  where it is used, or fix the depends attribute of the target in question to
  depend on the target which defines the reference/datatype.
  * <script> and <scriptdef> now set the current thread context.
  * Unrestrict the dbvendor names in the websphere element of the ejbjar task.
  Bugzilla Report 40475.
  * <env> nested element in <java>, <exec> and others is now case-insensitive
  for windows OS. Bugzilla Report 28874.
  * Removed support for xalan1 completely. Users of Xalan1 for Ant builds will
  have to stay at ant 1.6.5 or upgrade to xalan2.
  * Use org.apache.log4j.Logger instead of org.apache.log4j.Category.
  Category has been deprecated for ~2 years and has been removed from
  the log4j code.  Logger was introduced in log4j 1.2 so users of
  log4j 1.1 and log4j 1.0 need to upgrade to a newer version of log4j.
  Bugzilla Report 31951.
  * build.sysclasspath now also affects the bootclasspath handling of
  spawned Java VMs.  If you set build.sysclasspath to anything other
  than "ignore" (or leave it unset, since "ignore" is the default when
  it comes to bootclasspath handling), then the bootclasspath of the
  VM running Ant will be added to the bootclasspath you've specified.
  * The <java fork="false"> now as per default installs a security manager
  using the default permissions. This is now independent of the
  failonerror attribute.  Bugzilla report 33361.
  * <signjar> now notices when the jar and signedjar are equal, and switches
  to the same dependency logic as when signedjar is omitted. This may break
  something that depended upon signing in this situation. However, since
  invoking the JDK jarsigner program with -signedjar set to the source jar
  actually crashes the JVM on our (Java1.5) systems, we don't think any
  build files which actually worked will be affected by the change.
  * <signjar> used to ignore a nested fileset when a jar was also provided as an
  attribute, printing a warning message; now it signs files in the fileset.
  * An improved method of handling timestamp granularity differences between
  client and server was added to the <ftp> task.  FTP servers typically
  have HH:mm timestamps whereas local filesystems have HH:mm:ss timestamps.
  Previously, this required tweaking with the timediffmillis attribute
  which also was used to handle timezone differences.  Now, there is a new
  timestampgranularity attribute.  The default value for get operations is 0
  since the user has the more powerful preservelastmodified attribute to work
  with.  Since this is not available on put operations the default value
  adds a minute to the server timestamp in order to account for this,
  Scripts which previously used timediffmillis to do this compensation may
  need to be rewritten.  timediffmillis has now been deprecated.
  * On Java1.5+, Ant automatically sets the system property
  java.net.useSystemProxies to true, which gives it automatic use of the local
  IE (Windows) or Gnome2 (Unix/Linux) proxy settings. This may break any build
  file that somehow relied on content outside the firewall being unreachable:
  use the -noproxy command-line option to disable this new feature.
  Note that the Java1.5 proxy configuration system still does not
  appear to work reliably on Windows or Linux.
  * Support for the XSL:P XML parser has been removed.
  Bugzilla Report 23455.
  * Visual Age for Java optional tasks removed.
  * Testlet (test) optional task removed.
  * Icontract optional task removed.
  * Metamata (maudit, mmetrics, and mparse tasks) removed.
  * Sitraka (jpcoverage, jpcovmerge, jpcovreport) tasks suppressed.
  * <fixcrlf> used \r (Mac) line endings on OS X, whose proper line separator
  is \n (Unix).  Bugzilla report 39585.
  * <scp> now optionally supports the sftp protocol, you may need a
  newer jsch.jar.  Bugzilla Report 39373.
  * Ant launcher program prints errors to stderr, and exits with a 2 exit code
  value if, for any reason, it cannot actually start Ant proper. This will only
  affect programs/scripts that called the launcher and which did not want to
  receive an error if Ant itself would not start
  * All .NET tasks are now deprecated in favor of the new .NET Antlib:
  http://ant.apache.org/antlibs/dotnet/index.html
* Fri Sep 22 2006 dbornkessel@suse.de
- read in properties in /etc/ant.conf
- added source=1.4
* Mon May  8 2006 dbornkessel@suse.de
- only ant-antlr updates
* Thu Feb  2 2006 dbornkessel@suse.de
- fixed rpmlint errors and warnings
* Tue Jan 31 2006 dbornkessel@suse.de
- only ant-antlr updates
* Fri Jan 27 2006 dbornkessel@suse.de
- added four missing xsl files
- removed JAVA_HOME magic
* Tue Jan 24 2006 dbornkessel@suse.de
- Not dependend on xml-commons-apis, which are provided by xerces-j2, which does not
  depend on ant package (in contrast to old dependency on
  xml-commons-apis <-> ant)
- optional task are now again in extra spec file ant-antlr
* Thu Jan 19 2006 dbornkessel@suse.de
- Integrated ant and ant-antlr again in one spec file as there is no
  dependency loop ... jpackage BuildRequires were wrong.
- updated to version 1.6.5
* Mon Dec 19 2005 dbornkessel@suse.de
- added if statement that hinders unwanted creation of a file within a for loop
* Wed Sep 28 2005 dmueller@suse.de
- add norootforbuild
* Fri Mar  4 2005 skh@suse.de
- rely on jpackage-utils' java-functions to set JAVA_HOME correctly
* Sun Sep  5 2004 skh@suse.de
- create and add /usr/share/java/ant to file list for optional
  tasks to put their jars into
* Thu Sep  2 2004 skh@suse.de
- renamed from apache-ant to ant
- switched to JPackage 1.5 version
- updated to version 1.6.2
- split off optional tasks into separate package to solve build
  dependency loop in JPackage
